package avatar

import (
	"net/http"

	"github.com/zeromicro/go-zero/rest/httpx"

	"wechat-api/internal/logic/avatar"
	"wechat-api/internal/svc"
	"wechat-api/internal/types"
)

// swagger:route post /api/avatar/config avatar GetApiAvatarConfig
//
// get avatar configuration | 获取数字人配置信息
//
// get avatar configuration | 获取数字人配置信息
//
// Parameters:
//  + name: body
//    require: true
//    in: body
//    type: AvatarConfigReq
//
// Responses:
//  200: AvatarConfigResp

func GetApiAvatarConfigHandler(svcCtx *svc.ServiceContext) http.HandlerFunc {
	return func(w http.ResponseWriter, r *http.Request) {
		var req types.AvatarConfigReq
		if err := httpx.Parse(r, &req, true); err != nil {
			httpx.ErrorCtx(r.Context(), w, err)
			return
		}

		l := avatar.NewGetApiAvatarConfigLogic(r.Context(), svcCtx)
		resp, err := l.GetApiAvatarConfig(&req)
		if err != nil {
			httpx.ErrorCtx(r.Context(), w, err)
		} else {
			httpx.OkJsonCtx(r.Context(), w, resp)
		}
	}
}
