package avatar

import (
	"net/http"

	"github.com/zeromicro/go-zero/rest/httpx"

	"wechat-api/internal/logic/avatar"
	"wechat-api/internal/svc"
	"wechat-api/internal/types"
)

// swagger:route post /api/avatar/stop avatar StopApiAvatar
//
// stop avatar instance  | 停止数字人实例
//
// stop avatar instance  | 停止数字人实例
//
// Parameters:
//  + name: body
//    require: true
//    in: body
//    type: StopInstanceReq
//
// Responses:
//  200: StopInstanceResp

func StopApiAvatarHandler(svcCtx *svc.ServiceContext) http.HandlerFunc {
	return func(w http.ResponseWriter, r *http.Request) {
		var req types.StopInstanceReq
		if err := httpx.Parse(r, &req, true); err != nil {
			httpx.ErrorCtx(r.Context(), w, err)
			return
		}

		l := avatar.NewStopApiAvatarLogic(r.Context(), svcCtx)
		resp, err := l.StopApiAvatar(&req)
		if err != nil {
			httpx.ErrorCtx(r.Context(), w, err)
		} else {
			httpx.OkJsonCtx(r.Context(), w, resp)
		}
	}
}
