package chatrecords

import (
	"net/http"

	"github.com/zeromicro/go-zero/rest/httpx"

	"wechat-api/internal/logic/chatrecords"
	"wechat-api/internal/svc"
	"wechat-api/internal/types"
)

// swagger:route post /chat_records chatrecords GetChatRecordsById
//
// Get chat records by ID | 通过ID获取ChatRecords
//
// Get chat records by ID | 通过ID获取ChatRecords
//
// Parameters:
//  + name: body
//    require: true
//    in: body
//    type: IDReq
//
// Responses:
//  200: ChatRecordsInfoResp

func GetChatRecordsByIdHandler(svcCtx *svc.ServiceContext) http.HandlerFunc {
	return func(w http.ResponseWriter, r *http.Request) {
		var req types.IDReq
		if err := httpx.Parse(r, &req, true); err != nil {
			httpx.ErrorCtx(r.Context(), w, err)
			return
		}

		l := chatrecords.NewGetChatRecordsByIdLogic(r.Context(), svcCtx)
		resp, err := l.GetChatRecordsById(&req)
		if err != nil {
			httpx.ErrorCtx(r.Context(), w, err)
		} else {
			httpx.OkJsonCtx(r.Context(), w, resp)
		}
	}
}
