package chatrecords

import (
	"net/http"

	"github.com/zeromicro/go-zero/rest/httpx"

	"wechat-api/internal/logic/chatrecords"
	"wechat-api/internal/svc"
	"wechat-api/internal/types"
)

// swagger:route post /chat_records/list chatrecords GetChatRecordsList
//
// Get chat records list | 获取ChatRecords列表
//
// Get chat records list | 获取ChatRecords列表
//
// Parameters:
//  + name: body
//    require: true
//    in: body
//    type: ChatRecordsListReq
//
// Responses:
//  200: ChatRecordsListResp

func GetChatRecordsListHandler(svcCtx *svc.ServiceContext) http.HandlerFunc {
	return func(w http.ResponseWriter, r *http.Request) {
		var req types.ChatRecordsListReq
		if err := httpx.Parse(r, &req, true); err != nil {
			httpx.ErrorCtx(r.Context(), w, err)
			return
		}

		l := chatrecords.NewGetChatRecordsListLogic(r.Context(), svcCtx)
		resp, err := l.GetChatRecordsList(&req)
		if err != nil {
			httpx.ErrorCtx(r.Context(), w, err)
		} else {
			httpx.OkJsonCtx(r.Context(), w, resp)
		}
	}
}
