package chatsession

import (
	"net/http"

	"github.com/zeromicro/go-zero/rest/httpx"

	"wechat-api/internal/logic/chatsession"
	"wechat-api/internal/svc"
	"wechat-api/internal/types"
)

// swagger:route post /chat_session/create chatsession CreateChatSession
//
// Create chat session information | 创建ChatSession
//
// Create chat session information | 创建ChatSession
//
// Parameters:
//  + name: body
//    require: true
//    in: body
//    type: ChatSessionInfo
//
// Responses:
//  200: BaseMsgResp

func CreateChatSessionHandler(svcCtx *svc.ServiceContext) http.HandlerFunc {
	return func(w http.ResponseWriter, r *http.Request) {
		var req types.ChatSessionInfo
		if err := httpx.Parse(r, &req, true); err != nil {
			httpx.ErrorCtx(r.Context(), w, err)
			return
		}

		l := chatsession.NewCreateChatSessionLogic(r.Context(), svcCtx)
		resp, err := l.CreateChatSession(&req)
		if err != nil {
			httpx.ErrorCtx(r.Context(), w, err)
		} else {
			httpx.OkJsonCtx(r.Context(), w, resp)
		}
	}
}
