package chatsession

import (
	"net/http"

	"github.com/zeromicro/go-zero/rest/httpx"

	"wechat-api/internal/logic/chatsession"
	"wechat-api/internal/svc"
	"wechat-api/internal/types"
)

// swagger:route post /api/session/delete chatsession DeleteApiSession
//
// Delete chat session information | 删除ChatSession信息
//
// Delete chat session information | 删除ChatSession信息
//
// Parameters:
//  + name: body
//    require: true
//    in: body
//    type: IDsReq
//
// Responses:
//  200: BaseMsgResp

func DeleteApiSessionHandler(svcCtx *svc.ServiceContext) http.HandlerFunc {
	return func(w http.ResponseWriter, r *http.Request) {
		var req types.IDsReq
		if err := httpx.Parse(r, &req, true); err != nil {
			httpx.ErrorCtx(r.Context(), w, err)
			return
		}

		l := chatsession.NewDeleteApiSessionLogic(r.Context(), svcCtx)
		resp, err := l.DeleteApiSession(&req)
		if err != nil {
			httpx.ErrorCtx(r.Context(), w, err)
		} else {
			httpx.OkJsonCtx(r.Context(), w, resp)
		}
	}
}
