package chatsession

import (
	"net/http"

	"github.com/zeromicro/go-zero/rest/httpx"

	"wechat-api/internal/logic/chatsession"
	"wechat-api/internal/svc"
	"wechat-api/internal/types"
)

// swagger:route post /chat_session chatsession GetChatSessionById
//
// Get chat session by ID | 通过ID获取ChatSession
//
// Get chat session by ID | 通过ID获取ChatSession
//
// Parameters:
//  + name: body
//    require: true
//    in: body
//    type: IDReq
//
// Responses:
//  200: ChatSessionInfoResp

func GetChatSessionByIdHandler(svcCtx *svc.ServiceContext) http.HandlerFunc {
	return func(w http.ResponseWriter, r *http.Request) {
		var req types.IDReq
		if err := httpx.Parse(r, &req, true); err != nil {
			httpx.ErrorCtx(r.Context(), w, err)
			return
		}

		l := chatsession.NewGetChatSessionByIdLogic(r.Context(), svcCtx)
		resp, err := l.GetChatSessionById(&req)
		if err != nil {
			httpx.ErrorCtx(r.Context(), w, err)
		} else {
			httpx.OkJsonCtx(r.Context(), w, resp)
		}
	}
}
