package chatsession

import (
	"net/http"

	"github.com/zeromicro/go-zero/rest/httpx"

	"wechat-api/internal/logic/chatsession"
	"wechat-api/internal/svc"
	"wechat-api/internal/types"
)

// swagger:route post /chat_session/update chatsession UpdateChatSession
//
// Update chat session information | 更新ChatSession
//
// Update chat session information | 更新ChatSession
//
// Parameters:
//  + name: body
//    require: true
//    in: body
//    type: ChatSessionInfo
//
// Responses:
//  200: BaseMsgResp

func UpdateChatSessionHandler(svcCtx *svc.ServiceContext) http.HandlerFunc {
	return func(w http.ResponseWriter, r *http.Request) {
		var req types.ChatSessionInfo
		if err := httpx.Parse(r, &req, true); err != nil {
			httpx.ErrorCtx(r.Context(), w, err)
			return
		}

		l := chatsession.NewUpdateChatSessionLogic(r.Context(), svcCtx)
		resp, err := l.UpdateChatSession(&req)
		if err != nil {
			httpx.ErrorCtx(r.Context(), w, err)
		} else {
			httpx.OkJsonCtx(r.Context(), w, resp)
		}
	}
}
