package employee

import (
	"net/http"

	"github.com/zeromicro/go-zero/rest/httpx"

	"wechat-api/internal/logic/employee"
	"wechat-api/internal/svc"
	"wechat-api/internal/types"
)

// swagger:route post /employee/list employee GetEmployeeList
//
// Get employee list | 获取Employee列表
//
// Get employee list | 获取Employee列表
//
// Parameters:
//  + name: body
//    require: true
//    in: body
//    type: EmployeeListReq
//
// Responses:
//  200: EmployeeListResp

func GetEmployeeListHandler(svcCtx *svc.ServiceContext) http.HandlerFunc {
	return func(w http.ResponseWriter, r *http.Request) {
		var req types.EmployeeListReq
		if err := httpx.Parse(r, &req, true); err != nil {
			httpx.ErrorCtx(r.Context(), w, err)
			return
		}

		l := employee.NewGetEmployeeListLogic(r.Context(), svcCtx)
		resp, err := l.GetEmployeeList(&req)
		if err != nil {
			httpx.ErrorCtx(r.Context(), w, err)
		} else {
			httpx.OkJsonCtx(r.Context(), w, resp)
		}
	}
}
