package token

import (
	"net/http"

	"github.com/zeromicro/go-zero/rest/httpx"

	"wechat-api/internal/logic/token"
	"wechat-api/internal/svc"
	"wechat-api/internal/types"
)

// swagger:route post /token/check token CheckToken
//
// Check if token and mac are valid | 检查token和mac的合法性
//
// Check if token and mac are valid | 检查token和mac的合法性
//
// Parameters:
//  + name: body
//    require: true
//    in: body
//    type: CheckTokenReq
//
// Responses:
//  200: CheckTokenResp

func CheckTokenHandler(svcCtx *svc.ServiceContext) http.HandlerFunc {
	return func(w http.ResponseWriter, r *http.Request) {
		var req types.CheckTokenReq
		if err := httpx.Parse(r, &req, true); err != nil {
			httpx.ErrorCtx(r.Context(), w, err)
			return
		}

		l := token.NewCheckTokenLogic(r.Context(), svcCtx)
		resp, err := l.CheckToken(&req)
		if err != nil {
			httpx.ErrorCtx(r.Context(), w, err)
		} else {
			httpx.OkJsonCtx(r.Context(), w, resp)
		}
	}
}
