package token

import (
	"net/http"

	"github.com/zeromicro/go-zero/rest/httpx"

	"wechat-api/internal/logic/token"
	"wechat-api/internal/svc"
	"wechat-api/internal/types"
)

// swagger:route post /token/list token GetTokenList
//
// Get token list | 获取Token列表
//
// Get token list | 获取Token列表
//
// Parameters:
//  + name: body
//    require: true
//    in: body
//    type: TokenListReq
//
// Responses:
//  200: TokenListResp

func GetTokenListHandler(svcCtx *svc.ServiceContext) http.HandlerFunc {
	return func(w http.ResponseWriter, r *http.Request) {
		var req types.TokenListReq
		if err := httpx.Parse(r, &req, true); err != nil {
			httpx.ErrorCtx(r.Context(), w, err)
			return
		}

		l := token.NewGetTokenListLogic(r.Context(), svcCtx)
		resp, err := l.GetTokenList(&req)
		if err != nil {
			httpx.ErrorCtx(r.Context(), w, err)
		} else {
			httpx.OkJsonCtx(r.Context(), w, resp)
		}
	}
}
