package tutorial

import (
	"net/http"

	"github.com/zeromicro/go-zero/rest/httpx"

	"wechat-api/internal/logic/tutorial"
	"wechat-api/internal/svc"
	"wechat-api/internal/types"
)

// swagger:route post /tutorial/list tutorial GetTutorialList
//
// Get tutorial list | 获取Tutorial列表
//
// Get tutorial list | 获取Tutorial列表
//
// Parameters:
//  + name: body
//    require: true
//    in: body
//    type: TutorialListReq
//
// Responses:
//  200: TutorialListResp

func GetTutorialListHandler(svcCtx *svc.ServiceContext) http.HandlerFunc {
	return func(w http.ResponseWriter, r *http.Request) {
		var req types.TutorialListReq
		if err := httpx.Parse(r, &req, true); err != nil {
			httpx.ErrorCtx(r.Context(), w, err)
			return
		}

		l := tutorial.NewGetTutorialListLogic(r.Context(), svcCtx)
		resp, err := l.GetTutorialList(&req)
		if err != nil {
			httpx.ErrorCtx(r.Context(), w, err)
		} else {
			httpx.OkJsonCtx(r.Context(), w, resp)
		}
	}
}
