package aliyun_avatar

import (
	"context"

	"wechat-api/internal/svc"
	"wechat-api/internal/types"
	"wechat-api/internal/utils/dberrorhandler"

	"github.com/suyuan32/simple-admin-common/msg/errormsg"

	"github.com/zeromicro/go-zero/core/logx"
)

type CreateAliyunAvatarLogic struct {
	ctx    context.Context
	svcCtx *svc.ServiceContext
	logx.Logger
}

func NewCreateAliyunAvatarLogic(ctx context.Context, svcCtx *svc.ServiceContext) *CreateAliyunAvatarLogic {
	return &CreateAliyunAvatarLogic{
		ctx:    ctx,
		svcCtx: svcCtx,
		Logger: logx.WithContext(ctx),
	}
}

func (l *CreateAliyunAvatarLogic) CreateAliyunAvatar(req *types.AliyunAvatarInfo) (*types.BaseMsgResp, error) {
	_, err := l.svcCtx.DB.AliyunAvatar.Create().
		SetNotNilUserID(req.UserId).
		SetNotNilBizID(req.BizId).
		SetNotNilAccessKeyID(req.AccessKeyId).
		SetNotNilAccessKeySecret(req.AccessKeySecret).
		SetNotNilAppID(req.AppId).
		SetNotNilTenantID(req.TenantId).
		SetNotNilResponse(req.Response).
		SetNotNilToken(req.Token).
		SetNotNilSessionID(req.SessionId).
		Save(l.ctx)

	if err != nil {
		return nil, dberrorhandler.DefaultEntError(l.Logger, err, req)
	}

	return &types.BaseMsgResp{Msg: errormsg.CreateSuccess}, nil
}
