package sop_node

import (
	"context"
	"fmt"
	"github.com/suyuan32/simple-admin-common/msg/errormsg"
	"github.com/zeromicro/go-zero/core/errorx"
	"net/http"
	"wechat-api/ent/predicate"
	"wechat-api/ent/sopnode"
	"wechat-api/hook"
	"wechat-api/internal/utils/dberrorhandler"

	"wechat-api/internal/svc"
	"wechat-api/internal/types"

	"github.com/zeromicro/go-zero/core/logx"
)

type GetApiSopNodeListLogic struct {
	logx.Logger
	ctx    context.Context
	svcCtx *svc.ServiceContext
}

func NewGetApiSopNodeListLogic(ctx context.Context, svcCtx *svc.ServiceContext) *GetApiSopNodeListLogic {
	return &GetApiSopNodeListLogic{
		Logger: logx.WithContext(ctx),
		ctx:    ctx,
		svcCtx: svcCtx}
}

func (l *GetApiSopNodeListLogic) GetApiSopNodeList(req *types.BatchSopNodeListReq, r *http.Request) (*types.SopNodeListResp, error) {
	tokenStr := r.Header.Get("Authorization")
	_, err := hook.CheckDesktopAuth(tokenStr, l.svcCtx.DB)
	if err != nil {
		return nil, errorx.NewCodeInvalidArgumentError("check auth failed")
	}

	var predicates []predicate.SopNode
	if req.StageIds != nil && len(req.StageIds) > 0 {
		predicates = append(predicates, sopnode.StageIDIn(req.StageIds...))
	} else {
		return nil, dberrorhandler.DefaultEntError(l.Logger, fmt.Errorf("StageIds 不能为空"), req)
	}
	data, err := l.svcCtx.DB.SopNode.Query().Where(predicates...).All(l.ctx)

	if err != nil {
		return nil, dberrorhandler.DefaultEntError(l.Logger, err, req)
	}

	resp := &types.SopNodeListResp{}
	resp.Msg = errormsg.Success

	childNodeList, _ := GetSopNodeListByParentId(0, data)

	resp.Data = childNodeList

	return resp, nil
}
