package token

import (
	"context"

	"wechat-api/ent/predicate"
	"wechat-api/ent/token"
	"wechat-api/internal/svc"
	"wechat-api/internal/types"
	"wechat-api/internal/utils/dberrorhandler"

	"github.com/suyuan32/simple-admin-common/msg/errormsg"

	"github.com/suyuan32/simple-admin-common/utils/pointy"
	"github.com/zeromicro/go-zero/core/logx"
)

type GetTokenListLogic struct {
	ctx    context.Context
	svcCtx *svc.ServiceContext
	logx.Logger
}

func NewGetTokenListLogic(ctx context.Context, svcCtx *svc.ServiceContext) *GetTokenListLogic {
	return &GetTokenListLogic{
		ctx:    ctx,
		svcCtx: svcCtx,
		Logger: logx.WithContext(ctx),
	}
}

func (l *GetTokenListLogic) GetTokenList(req *types.TokenListReq) (*types.TokenListResp, error) {
	var predicates []predicate.Token
	if req.Token != nil {
		predicates = append(predicates, token.TokenContains(*req.Token))
	}
	if req.Mac != nil {
		predicates = append(predicates, token.MACContains(*req.Mac))
	}
	data, err := l.svcCtx.DB.Token.Query().Where(predicates...).Page(l.ctx, req.Page, req.PageSize)

	if err != nil {
		return nil, dberrorhandler.DefaultEntError(l.Logger, err, req)
	}

	resp := &types.TokenListResp{}
	resp.Msg = errormsg.Success
	resp.Data.Total = data.PageDetails.Total

	for _, v := range data.List {
		expireAtStr := v.ExpireAt.Format("2006-01-02 15:04:05")
		resp.Data.Data = append(resp.Data.Data,
			types.TokenInfo{
				BaseIDInfo: types.BaseIDInfo{
					Id:        &v.ID,
					CreatedAt: pointy.GetPointer(v.CreatedAt.UnixMilli()),
					UpdatedAt: pointy.GetPointer(v.UpdatedAt.UnixMilli()),
				},
				ExpireAt:       pointy.GetUnixMilliPointer(v.ExpireAt.UnixMilli()),
				ExpireAtStr:    &expireAtStr,
				Token:          &v.Token,
				Mac:            &v.MAC,
				OrganizationId: &v.OrganizationID,
			})
	}

	return resp, nil
}
